@@ -1,5 +1,5 @@
 #-*- encoding: utf-8 -*-
-VERSION='0.3.0'
+VERSION='0.3.5'
 import sys
 try:
     from urllib.request import urlopen, Request
@@ -17,7 +17,6 @@ class JSONScraper(object):
     '''
     Encapsulates execution request and parsing of response
     '''
-    
     def __init__(self, logger):
         object.__init__(self)
         self.logger = logger
@@ -43,7 +42,7 @@ class JSONScraper(object):
         except:
             raise TwitchException(TwitchException.HTTP_ERROR)
         return data
-        
+
     '''
         Download Data from an url and returns it as JSON
         @param url Url to download from
@@ -200,17 +199,7 @@ class TwitchTV(object):
         playlistQualities = M3UPlaylist(playlistQualitiesData)
 
         vodUrl = playlistQualities.getQuality(maxQuality)
-        vodUrlBase = vodUrl[:-14]
-        vodUrlData = self.scraper.downloadWebData(vodUrl)
-
-        lines = vodUrlData.splitlines()
-        linesIterator = iter(lines)
-
-        for line in linesIterator:
-            if line.startswith('#EXTINF'):
-                segment = next(linesIterator)
-                segmentUrl = vodUrlBase + segment
-                playlist+=[(segmentUrl, ())]
+        playlist+=[(vodUrl, ())]
 
         return playlist
 
@@ -282,22 +271,42 @@ class Keys(object):
     string-constants
     '''
 
+    BITRATE = 'bitrate'
     CHANNEL = 'channel'
     CHANNELS = 'channels'
     CONNECT = 'connect'
+    BACKGROUND = 'background'
     DISPLAY_NAME = 'display_name'
     FEATURED = 'featured'
     FOLLOWS = 'follows'
+    GAME = 'game'
     LOGO = 'logo'
+    BOX = 'box'
+    LARGE = 'large'
     NAME = 'name'
+    NEEDED_INFO = 'needed_info'
+    PLAY = 'play'
+    PLAYPATH = 'playpath'
+    QUALITY = 'quality'
+    RTMP = 'rtmp'
     STREAMS = 'streams'
+    REFERER = 'Referer'
+    RTMP_URL = 'rtmpUrl'
+    STATUS = 'status'
     STREAM = 'stream'
+    SWF_URL = 'swfUrl'
     TEAMS = 'teams'
+    TOKEN = 'token'
     TOP = 'top'
     TOTAL = '_total'
     USER_AGENT = 'User-Agent'
     USER_AGENT_STRING = 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0) Gecko/20100101 Firefox/6.0'
     VIDEOS = 'videos'
+    VIDEO_BANNER = 'video_banner'
+    VIDEO_HEIGHT = 'video_height'
+    VIEWERS = 'viewers'
+    PREVIEW = 'preview'
+    TITLE = 'title'
 
     QUALITY_LIST_STREAM = ['Source', "High", "Medium", "Low", "Mobile"]
     QUALITY_LIST_VIDEO = ['live', "720p", "480p", "360p", "226p"]
